# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr
from conekta.models.order_response_fiscal_entity_address import OrderResponseFiscalEntityAddress

class OrderResponseFiscalEntity(BaseModel):
    """
    OrderResponseFiscalEntity
    """
    address: Optional[OrderResponseFiscalEntityAddress] = None
    tax_id: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    object: Optional[StrictStr] = None
    __properties = ["address", "tax_id", "id", "object"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrderResponseFiscalEntity:
        """Create an instance of OrderResponseFiscalEntity from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrderResponseFiscalEntity:
        """Create an instance of OrderResponseFiscalEntity from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OrderResponseFiscalEntity.parse_obj(obj)

        _obj = OrderResponseFiscalEntity.parse_obj({
            "address": OrderResponseFiscalEntityAddress.from_dict(obj.get("address")) if obj.get("address") is not None else None,
            "tax_id": obj.get("tax_id"),
            "id": obj.get("id"),
            "object": obj.get("object")
        })
        return _obj

