# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.tokens_api import TokensApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestTokensApi(unittest.TestCase):
    """TokensApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.tokens_api.TokensApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_token(self):
        """Test case for create_token

        Create Token  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.Token(
            card=conekta.TokenCard(
                cvc='123',
                exp_month='07',
                exp_year='27',
                name='Foo Foo',
                number='5475040095304607'
            )
        )
        response = self.api.create_token(rq, accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()
