# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from conekta.models.token_card import TokenCard
from conekta.models.token_checkout import TokenCheckout

class Token(BaseModel):
    """
    a token
    """
    card: Optional[TokenCard] = None
    checkout: Optional[TokenCheckout] = None
    __properties = ["card", "checkout"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Token:
        """Create an instance of Token from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of checkout
        if self.checkout:
            _dict['checkout'] = self.checkout.to_dict()
        # set to None if card (nullable) is None
        # and __fields_set__ contains the field
        if self.card is None and "card" in self.__fields_set__:
            _dict['card'] = None

        # set to None if checkout (nullable) is None
        # and __fields_set__ contains the field
        if self.checkout is None and "checkout" in self.__fields_set__:
            _dict['checkout'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Token:
        """Create an instance of Token from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Token.parse_obj(obj)

        _obj = Token.parse_obj({
            "card": TokenCard.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "checkout": TokenCheckout.from_dict(obj.get("checkout")) if obj.get("checkout") is not None else None
        })
        return _obj

