# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import conekta
from conekta.api.balances_api import BalancesApi  # noqa: E501
from conekta.rest import ApiException


class TestBalancesApi(unittest.TestCase):
    """BalancesApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.balances_api.BalancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_balance(self):
        """Test case for get_balance

        Get a company's balance  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
